"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.applicationSchematic = exports.applicationGenerator = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const add_capacitor_1 = require("./lib/add-capacitor");
const add_dependencies_1 = require("./lib/add-dependencies");
const add_react_1 = require("./lib/add-react");
const files_1 = require("./lib/files");
const normalize_options_1 = require("./lib/normalize-options");
const update_workspace_1 = require("./lib/update-workspace");
const change_react_router_1 = require("./lib/change-react-router");
const remove_plain_reactapp_1 = require("./lib/remove-plain-reactapp");
const update_jest_babel_setup_1 = require("./lib/update-jest-babel-setup");
const update_cypress_setup_1 = require("./lib/update-cypress-setup");
function applicationGenerator(host, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const normalizedOptions = (0, normalize_options_1.normalizeOptions)(host, options);
        const installTask = (0, add_dependencies_1.addDependencies)(host);
        const reactTask = yield (0, add_react_1.addReact)(host, options);
        const routerTask = (0, change_react_router_1.changeReactRouter)(host);
        (0, files_1.addFiles)(host, normalizedOptions);
        (0, files_1.deleteUnusedFiles)(host, normalizedOptions);
        (0, update_workspace_1.updateWorkspace)(host, normalizedOptions);
        (0, remove_plain_reactapp_1.removePlainReactapp)(host, normalizedOptions);
        (0, update_jest_babel_setup_1.updateJestBabelSetup)(host, normalizedOptions);
        (0, update_cypress_setup_1.updateCypressSetup)(host, normalizedOptions);
        // eslint-disable-next-line @typescript-eslint/no-empty-function
        let capacitorTask = () => { };
        if (options.capacitor) {
            capacitorTask = yield (0, add_capacitor_1.addCapacitor)(host, normalizedOptions);
        }
        if (!options.skipFormat) {
            yield (0, devkit_1.formatFiles)(host);
        }
        return (0, devkit_1.runTasksInSerial)(installTask, reactTask, routerTask, capacitorTask);
    });
}
exports.applicationGenerator = applicationGenerator;
exports.default = applicationGenerator;
exports.applicationSchematic = (0, devkit_1.convertNxGenerator)(applicationGenerator);
//# sourceMappingURL=generator.js.map